# sorting-wizard

This is a WIP python packages that aims to achieve sort algorithm implementations.

## Algorithms

Algorithms implemented so far:

### Stable

- [X] Bubble Sort
- [ ] Cocktail Shaker Sort (Bidirectional Bubble Sort)
- [ ] Insertion Sort
- [ ] Merge Sort
- [ ] Tim Sort
- [ ] Block Sort
- [ ] Cube Sort
- [ ] Tree Sort
- [ ] Gnome Sort
- [ ] Odd-even Sort

### Unstable

- [ ] Quicksort
- [ ] Introsort
- [ ] Heapsort
- [ ] Selection Sort
- [ ] Library Sort (Gapped Insertion Sort)
- [ ] Shellsort
- [ ] Exchange Sort
- [ ] Cycle Sort
- [ ] Patience Sort
- [ ] Tournament sort
- [ ] Comb sort
